@@ -24,10 +24,12 @@
 #include <QDomNode>
 #include <QStandardItemModel>
 
-#include <kurl.h>
-#include <kxmlguiwindow.h>
+#include <QAction>
+#include <QIcon>
+#include <QUrl>
+#include <KXmlGuiWindow>
 
-#include "phrasebook.h"
+//#include "phrasebook.h"
 #include "ui_phrasebookdialog.h"
 
 class KActionMenu;
@@ -38,33 +40,21 @@ class KToolBarPopupAction;
  * inserting a standard phrase book.
  * @author Gunnar Schmi Dt
  */
-class StandardPhraseBookInsertAction : public KAction
+class StandardPhraseBookInsertAction : public QAction
 {
     Q_OBJECT
 public:
-    StandardPhraseBookInsertAction(const KUrl &url, const QString& name, const QObject* receiver, const char* slot, KActionCollection* parent)
-        : KAction(KIcon(QLatin1String("phrasebook")), name, parent)
-    {
-        this->url = url;
-        connect(this, SIGNAL(triggered(bool)), this, SLOT(slotActivated()));
-        connect(this, SIGNAL(slotActivated(const KUrl &)), receiver, slot);
-        parent->addAction(name, this);
-    }
-    ~StandardPhraseBookInsertAction()
-    {
-    }
+    StandardPhraseBookInsertAction(const QUrl &url, const QString& name, const QObject* receiver, const char* slot, KActionCollection* parent);
+    ~StandardPhraseBookInsertAction();
 
 public slots:
-    void slotActivated()
-    {
-        emit slotActivated(url);
-    }
+    void slotActivated();
 
 signals:
-    void slotActivated(const KUrl &url);
+    void slotActivated(const QUrl &url);
 
 private:
-    KUrl url;
+    QUrl url;
 };
 
 /**
@@ -92,7 +82,7 @@ public:
     /** Destructor. */
     ~PhraseBookDialog();
 
-    bool queryClose();
+    bool queryClose() override;
 
 public slots:
     void slotTextChanged(const QString &s);
@@ -113,7 +103,7 @@ public slots:
 
     void slotSave();
     void slotImportPhrasebook();
-    void slotImportPhrasebook(const KUrl &url);
+    void slotImportPhrasebook(const QUrl &url);
     void slotExportPhrasebook();
     //void slotPrint ();
 
