@@ -21,15 +21,14 @@
 #ifndef TEXTTOSPEECHSYSTEM_H
 #define TEXTTOSPEECHSYSTEM_H
 
-#include <QtCore/QList>
-#include <QtCore/QObject>
+#include <QList>
+#include <QObject>
 
-class KConfig;
+class QTextToSpeech;
 
 /**This class represents a text-to-speech system.
   *@author Gunnar Schmi Dt
   */
-
 class TextToSpeechSystem : public QObject
 {
     Q_OBJECT
@@ -38,8 +37,8 @@ public:
     TextToSpeechSystem();
     ~TextToSpeechSystem();
 
-    void readOptions(KConfig *config, const QString &langGroup);
-    void saveOptions(KConfig *config, const QString &langGroup);
+    void readOptions(const QString &langGroup);
+    void saveOptions(const QString &langGroup);
 
 public slots:
     void speak(const QString &text, const QString &language);
@@ -51,7 +50,9 @@ private:
     int codec;
     QString ttsCommand;
     bool stdIn;
-    bool useKttsd;
+    bool useQtSpeech;
+    /** Text to Speech API */
+    QTextToSpeech *m_speech;
 };
 
 #endif
